{# HEADER #}
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" lang="en">
<head>
	<meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
	<title></title>
	<meta name="viewport" content="width=device-width, initial-scale=1.0"/>
</head>

{# BODY #}

<body style="margin: 0; padding: 0;">
<table align="center" border="0" cellpadding="0" cellspacing="0" width="320" style="border: none; border-collapse: collapse; font-family:  Arial, sans-serif; font-size: 14px; line-height: 1.5;">

	<tr>
		<td><br/></td>
	</tr>
	{# INTRO #}
	<tr>
		<td>Hi there,</td>
	</tr>
	<tr>
		<td><br/></td>
	</tr>
	{% block content %}
	{% endblock %}
	{# FOOTER #}
	<tr>
		<td><br/></td>
	</tr>
	{% if team_name %}
		<tr>
			<td>Yours Truly,</td>
		</tr>
		<tr>
			<td>The team at {{ team_name }}</td>
		</tr>
	{% else %}
		<td>Thank you for using our site!</td>
	{% endif %}
</table>
</body>
</html>